## IOWeb Framework

![pytest status](https://github.com/lorien/ioweb/workflows/pytest/badge.svg)
![pytype status](https://github.com/lorien/ioweb/workflows/pytype/badge.svg)

A thing to build web crawlers.

Good things:

 * it probably will not format your disk

Bad things:

 * lacks tests
 * lacks documentation

## Feedback

 * [t.me/grablab](https://t.me/grablab) - English chat about web scraping
 * [t.me/grablab_ru](https://t.me/grablab_ru) - Russian chat about web scraping
